<template>
  <el-dialog
    v-diadrag
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="120px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件族编号" prop="partFamilyNo">
            <el-input
              v-model="dataForm.partFamilyNo"
              placeholder="零件族编号"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="零件族名称" prop="partFamilyName">
            <el-input
              v-model="dataForm.partFamilyName"
              placeholder="零件族名称"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="备注" prop="remark">
            <el-input v-model="dataForm.remark" placeholder="备注"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="检验规则" prop="testRuleId">
            <el-select
              v-model="dataForm.testRuleId"
              filterable
              clearable
              placeholder="请选择"
              style="width: 100%;"
            >
              <el-option
                v-for="(item, index) in this.ruleOptions"
                :key="index"
                :label="item.ruleName"
                :value="item.id"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj } from '@/api/basic/partFamily'
import { getTestRuleList } from '../../../api/quality/testrule'

export default {
  data() {
    return {
      ruleOptions: [],
      visible: false,
      dataForm: {
        id: 0,
        partFamilyNo: '',
        partFamilyName: '',
        remark: '',
        testRuleId: null
      },
      dataRule: {
        partFamilyNo: [
          { required: true, message: '零件族编号不能为空', trigger: 'blur' }
        ],
        partFamilyName: [
          { required: true, message: '零件族名称不能为空', trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },
  mounted() {
    this.initTestRuleSelect()
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    initTestRuleSelect() {
      getTestRuleList().then((response) => {
        this.ruleOptions = response.data
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
